==> bonita-server-7.3.3-sources.jar: org/bonitasoft/engine/page/SPageBuilderFactory.java <==
/**
 * Copyright (C) 2015 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.page;

/**
 * @author Matthieu Chaffotte
 */
public interface SPageBuilderFactory {

    SPageBuilder createNewInstance(String name, String description, String displayName, long installationDate, long installedBy, boolean provided,
                                   String contentName);

    SPageBuilder createNewInstance(String name, long installationDate, int installedBy, boolean provided, String contentName);

    String getIdKey();

    String getNameKey();

    String getDisplayNameKey();

    String getDescriptionKey();

    String getProvidedKey();

    String getInstallationDateKey();

    String getLastModificationDateKey();

    String getLastUpdatedByKey();

    String getInstalledByKey();

    String getContentTypeKey();

    String getProcessDefinitionIdKey();

}

==> bonita-server-7.8.4-sources.jar: org/bonitasoft/engine/page/SPageBuilderFactory.java <==
/**
 * Copyright (C) 2015 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.page;

/**
 * @author Matthieu Chaffotte
 */
public interface SPageBuilderFactory {

    SPageBuilder createNewInstance(String name, String description, String displayName, long installationDate, long installedBy, boolean provided, boolean hidden,
                                   String contentName);

    SPageBuilder createNewInstance(String name, long installationDate, int installedBy, boolean provided, String contentName);

    String getIdKey();

    String getNameKey();

    String getDisplayNameKey();

    String getDescriptionKey();

    String getProvidedKey();

    String getHiddenKey();

    String getInstallationDateKey();

    String getLastModificationDateKey();

    String getLastUpdatedByKey();

    String getInstalledByKey();

    String getContentTypeKey();

    String getProcessDefinitionIdKey();

}
